@@ -3,11 +3,12 @@ use strict;
 use warnings;
 
 package Metabase::Fact;
-our $VERSION = '0.024'; # VERSION
+
+our $VERSION = '0.025';
 
 use Carp ();
 use Data::GUID guid_string => { -as => '_guid' };
-use JSON 2 ();
+use JSON::MaybeXS ();
 use Metabase::Resource;
 
 #--------------------------------------------------------------------------#
@@ -309,12 +310,12 @@ sub from_struct {
 
 sub as_json {
     my ($self) = @_;
-    return JSON->new->ascii->encode( $self->as_struct );
+    return JSON::MaybeXS->new(ascii => 1)->encode( $self->as_struct );
 }
 
 sub from_json {
     my ( $class, $string ) = @_;
-    my $struct = eval { JSON->new->ascii->decode($string) }
+    my $struct = eval { JSON::MaybeXS->new(ascii => 1)->decode($string) }
       or Carp::confess "Error decoding JSON:\n$@";
     return $class->from_struct($struct);
 }
@@ -417,7 +418,7 @@ Metabase::Fact - base class for Metabase Facts
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 SYNOPSIS
 
@@ -888,6 +889,8 @@ H.Merijn Brand <hmbrand@cpan.org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords David Steinbrunner Karen Etheridge Nathan Gary Glenn Randy Stauner
+
 =over 4
 
 =item *
@@ -910,7 +913,7 @@ Randy Stauner <rwstauner@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by David Golden.
+This software is Copyright (c) 2016 by David Golden.
 
 This is free software, licensed under:
 
